diff include/SDL_video.h @ 1734:f7c667ded87d SDL-1.3

The general code handles restoring video mode/gamma/etc. when the window loses focus. Support for changing fullscreen/windowed mode in progress.
author Sam Lantinga <slouken@libsdl.org>
date Sun, 09 Jul 2006 18:09:16 +0000
parents 0b1070f2f94d
children 8dd28c4ef746
line wrap: on
line diff
--- a/include/SDL_video.h	Sun Jul 09 09:02:26 2006 +0000
+++ b/include/SDL_video.h	Sun Jul 09 18:09:16 2006 +0000
@@ -125,7 +125,7 @@
     SDL_WINDOW_MINIMIZED = 0x00000020,          /**< minimized */
     SDL_WINDOW_MAXIMIZED = 0x00000040,          /**< maximized */
     SDL_WINDOW_INPUT_GRABBED = 0x00000100,      /**< window has grabbed input focus */
-    SDL_WINDOW_KEYBOARD_FOCUS = 0x00000200,     /**< window has keyboard focus */
+    SDL_WINDOW_INPUT_FOCUS = 0x00000200,        /**< window has input focus */
     SDL_WINDOW_MOUSE_FOCUS = 0x00000400,        /**< window has mouse focus */
 } SDL_WindowFlags;
 
@@ -734,7 +734,7 @@
 /**
  * \fn void SDL_RaiseWindow(SDL_WindowID windowID)
  *
  * \brief Raise the window so it's above other windows.
  */
 extern DECLSPEC void SDLCALL SDL_RaiseWindow(SDL_WindowID windowID);
@@ -734,7 +734,7 @@
  * \fn void SDL_RaiseWindow(SDL_WindowID windowID)
  *
- * \brief Raise the window so it's above other windows.
+ * \brief Raise the window above other windows and set the input focus.
  */
 extern DECLSPEC void SDLCALL SDL_RaiseWindow(SDL_WindowID windowID);